
# Class: Datasets




URI: [nwb_schema_language:Datasets](https://w3id.org/p2p_ld/nwb-schema-language/Datasets)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Dataset]<datasets%200..*-++[Datasets],[Dataset])](https://yuml.me/diagram/nofunky;dir:TB/class/[Dataset]<datasets%200..*-++[Datasets],[Dataset])

## Attributes


### Own

 * [datasets](datasets.md)  <sub>0..\*</sub>
     * Range: [Dataset](Dataset.md)
